import { View, Input, Button, Image, Text, Textarea } from '@tarojs/components'
import { useCallback, useEffect, useMemo, useRef, useState, ReactNode, memo } from 'react'
import styles from "./index.module.scss"
import classnames from "classnames";
import Taro, { faceVerifyForPay, useDidShow, useRouter } from '@tarojs/taro'
import { formatDateTime, formatHashTag, formatImgUrl, formatPriceDiv, formatWeightDiv } from '@/common/format'
import {
    mpreturnApplyOrder,
    mpenumrefundExplainone,
} from "@/api/order"
import Popup from '@/components/popup'


export default () => {

    useEffect(() => {
        getEnum()
    }, [])
    const Router = useRouter()

    //获取枚举
    const [List, setList] = useState<any[]>([])
    const { fetchData: explanFetch } = mpenumrefundExplainone()
    const getEnum = async () => {
        const res = await explanFetch()
        if (res.data) {
            setList(res.data.list)
        }
    }

    //选择退货原因
    const handReasonOne = (item) => {
        List.map(it => {
            if (it.id === item.id) {
                it.default = true
            } else {
                it.default = false
            }
            return it
        })
        setList([...List])
        setQuery((val) => ({ ...val, reasonId: item.id }))
        queryRef.current.reasonName = item.name
    }

    //筛选内容展示
    const [showPopup, setshowPopup] = useState(false)

    const queryRef = useRef({
        reasonName: '请选择'
    })
    const [Query, setQuery] = useState<any>({
        reasonId: '',
        reasonName: '请选择'
    })


    //备注信息
    const [TextareaValue, setTextareaValue] = useState('')
    const getDesc = (e) => {
        setTextareaValue(e)
    }

    //取消返回
    const handCancl = () => {
        Taro.navigateBack({
            delta: 1
        })
    }

    //确认选择
    const handSlect = () => {
        setQuery((val) => ({ ...val, reasonName: queryRef.current.reasonName }))
        setshowPopup(false)
    }

    //重置
    const handReset = () => {
        setQuery(({ reasonId: '', reasonName: '请选择' }))
        queryRef.current.reasonName = '请选择'
        const arrOne = resetArr(List)
        setList([...arrOne])
    }

    //判断是否允许提交
    const isDisabled = useMemo(() => {
        if (Query.reasonId !== '') {
            return false
        } else {
            return true
        }
    }, [Query])

    //数组重置
    const resetArr = (arr) => {
        arr.map(it => {
            it.default = false
            return it
        })
        return arr
    }
    //确认退款
    const { fetchData: sureFetch } = mpreturnApplyOrder()
    const handSure = () => {
        const query = {
            reason_describe: TextareaValue,
            fabric_piece_accessory_url: [],
            goods_status: 100,
            return_explain: Query.reasonId,
            roll: 0,
            roll_list: [],
            sale_order_id: Number(Router.params.orderId),
        };
        Taro.showModal({
            content: "确认退款吗？",
            confirmText: "确认",
            cancelText: "取消",
            success: async function (res) {
                if (res.confirm) {
                    Taro.showLoading({
                        title: '请稍等...',
                        mask: true
                    })
                    const res = await sureFetch(query)
                    if (res?.msg === 'success') {
                        Taro.showToast({
                            title: '成功'
                        })
                        Taro.hideLoading()
                        handCancl()
                    } else {
                        Taro.hideLoading()
                        Taro.showToast({
                            title: res?.msg,
                            icon: 'error'
                        })
                    }
                }

            }
        })
    }

    return (
        <View className={styles.main}>
            <View className={styles.resonBig}>
                <View className={styles.reasonItem} onClick={() => { setshowPopup(true) }}>
                    <View className={styles.reasonLeft}>
                        <View className={styles.reasonFont}>退货原因</View>
                        <Text className={styles.xing}>*</Text>
                        {
                            Query.reasonName === '请选择' && <View className={styles.selectFont}>请选择</View>
                        }
                        {
                            Query.reasonName !== '请选择' && <View className={styles.selectFont}>{Query.reasonName}</View>
                        }
                    </View>
                    <View className={classnames('iconfont', 'icon-chakanquanbukehu', styles.chakanquanbukehu)}></View>
                </View>
            </View>
            <View className={styles.descBox}>
                <View className={styles.title}>其他说明</View>
                <View className={styles.textBox}>
                    <Textarea
                        onInput={(e) => getDesc(e.detail.value)}
                        value={TextareaValue}
                        // style='background:#f6f6f6;height:210px;padding:15rpx 24rpx 24rpx 24rpx;border-radius: 8rpx;'
                        placeholderStyle='font-size: 28rpx;font-weight: 400;'
                        autoFocus
                        placeholder={'选填/退货说明中选择时（其他问题）必填'}
                    ></Textarea>
                </View>
            </View>
            <View className={styles.safeBox}>
                <View className={styles.bottomBox}>

                    <Button className={styles.resetBox} onClick={() => { handCancl() }}> 取消</Button >
                    <Button className={classnames(isDisabled ? styles.button : styles.activeButton)} disabled={isDisabled} onClick={() => handSure()}> 确认退款</Button >
                </View>
            </View>
            <Popup title={'筛选情况'} show={showPopup} onClose={() => { setshowPopup?.(false) }}>

                <View className={styles.popupBox}>
                    <View className={styles.thirdBox}>
                        <View className={styles.thirdTopfont}>退款原因</View>
                        <View className={styles.flexModebox}>
                            {
                                List.map((item, index) => {
                                    return (
                                        <View onClick={() => { handReasonOne(item) }} className={classnames(item.default ? styles.activemodeBox : styles.modeBox)} key={index}>{item.name}</View>
                                    )
                                })
                            }
                        </View>
                    </View>
                    <View style={{ height: '100rpx' }}></View>
                    <View className={styles.bottomBox1}>

                        <Button className={styles.resetBox1} onClick={() => { handReset() }}> 重置</Button >
                        <Button className={classnames(isDisabled ? styles.button1 : styles.activeButton1)} disabled={isDisabled} onClick={() => handSlect()}> 确认</Button >
                    </View>
                </View>
            </Popup>
        </View>
    )
}