import { FC, ReactNode, useEffect, useImperativeHandle, useMemo, useRef, useState } from 'react'
import { InternalShoppingCartAction, ShoppingCartAction, ShoppingContext, useShoppingCart } from '../../context'
import { GoodsMeta, ColorStore, ShoppingContextValue } from '../../context'

export type TriggerCheckboxOptions = {
  colorStore: ColorStore
  changedCheckbox: GoodsMeta
  currentCheckedPurchaserId: ShoppingContextValue['currentCheckedPurchaserId']
  setSelectedAmount: ShoppingContextValue['setSelectedAmount']
}

export interface ShoppingCartPropsType {
  initialValues?: ColorStore
  onTriggerCheckbox?: (options: TriggerCheckboxOptions) => void
  children?: ReactNode
  ref?: ShoppingCartAction
}
// 购物车上下文组件
export const ShoppingCart: FC<ShoppingCartPropsType> = (props) => {
  const { children, onTriggerCheckbox, initialValues, ref: refProps } = props
  console.log('重新渲染 ShoppingCart context', refProps)

  const defaultShoppingCart = useShoppingCart()

  const ref = (refProps || defaultShoppingCart) as InternalShoppingCartAction

  const onTriggerCheckboxRef = useRef(onTriggerCheckbox)
  onTriggerCheckboxRef.current = onTriggerCheckbox

  const [colorStore, setColorStore] = useState<ColorStore>(() => initialValues || {})
  const [changedCheckbox, setChangedCheckbox] = useState<GoodsMeta>({} as GoodsMeta)
  // 当前高亮的客户
  const [currentCheckedPurchaserId, setCurrentCheckedPurchaserId] = useState<number>(-1)
  const [currentCheckedSaleMode, setCurrentCheckedSaleMode] = useState<number>(0)
  // 是否管理状态
  const [isManageStatus, setManageStatus] = useState(false)

  const [selectedAmount, setSelectedAmount] = useState(0)

  const ctx: ShoppingContextValue = useMemo(() => {
    console.log('useMemo ShoppingContextValue')
    return {
      isManageStatus,
      setManageStatus,
      currentCheckedPurchaserId, // 当前高亮的客户
      setCurrentCheckedPurchaserId, // 设置高亮当前客户
      currentCheckedSaleMode,
      setCurrentCheckedSaleMode,
      colorStore,
      setChangedCheckbox(changedGoods) {
        console.log('changedGoods==>', colorStore, changedGoods)
        setColorStore((prev) => ({
          ...prev,
          [changedGoods.purchaserId as number]: {
            purchaserId: changedGoods.purchaserId,
            goodsKind: { ...prev[changedGoods.purchaserId]?.goodsKind, ...changedGoods.goodsKind },
            checked: changedGoods.checked,
          },
        }))
        setChangedCheckbox(changedGoods)
      },
      setColorStore,
      selectedAmount,
      setSelectedAmount,
    }
  }, [colorStore, currentCheckedPurchaserId, isManageStatus, selectedAmount])
  // 暴露给外界
  useImperativeHandle(
    ref.__INTERNAL__,
    () => ({
      getManageStatus() {
        return ctx.isManageStatus
      },
      setManageStatus: ctx.setManageStatus,
    }),
    [ctx.isManageStatus, ctx.setManageStatus],
  )

  // 这里要在 useEffect 也就是刷新 state 后再调用，否则如果在 onFieldsChangeRef 修改值会覆盖掉上次修改
  useEffect(() => {
    onTriggerCheckboxRef.current?.({
      colorStore,
      changedCheckbox,
      currentCheckedPurchaserId,
      setSelectedAmount,
    })
  }, [colorStore, changedCheckbox, currentCheckedPurchaserId])

  return <ShoppingContext.Provider value={ctx}>{children}</ShoppingContext.Provider>
}
