import { Text, View } from '@tarojs/components'
import { FC, memo, useCallback, useContext, useEffect, useMemo, useRef, useState } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import { formatPriceDiv } from '@/common/format'
import Taro, { useDidShow } from '@tarojs/taro'
import LayoutBlock from '@/components/layoutBlock'
import MCheckbox from '@/components/checkbox'
import Tag from '@/components/tag'
import Divider from '@/components/divider'
import NormalButton from '@/components/normalButton'
import ColorKindItem from '../colorKindItem'
import { EnumSaleMode } from '@/common/Enumerate'
import { useNeedMemoCallback } from '@/use/useCommon'
import { selectList } from '../../config'
import { useShoppingContext } from '../../context'

type PropsType = {
  itemData?: ShoppingCartData
}

const DrawerButton = memo<{ isOpen: boolean }>(({ isOpen }) => {
  return (
    <View className={styles.drawerButton}>{isOpen ? <Text className='iconfont icon-shouqi'></Text> : <Text className='iconfont icon-zhankai'></Text>}</View>
  )
})

enum BackEndSaleModeListFieldMap {
  bulk_color_list = 0,
  length_cut_color_list = 1,
  weight_cut_color_list = 2,
}

export default memo<PropsType>((props) => {
  console.log('props==>', props)
  const { itemData } = props

  const { setCurrentCheckedSaleMode } = useShoppingContext()

  console.log('重新渲染 shoppingCartItem')
  const [openDetail, setOpenDetail] = useState(false)

  const handleOpenDetail = () => {
    setOpenDetail((isOpen) => !isOpen)
    handleClickLayout()
  }

  const [selected, setSelect] = useState<EnumSaleMode>(0)

  const onSelectOrderType = (type: EnumSaleMode) => {
    setSelect(type)
    setCurrentCheckedSaleMode(type)
    // 重置预估金额
    setSelectedAmount(0)
  }

  const saleModeList = useRef({
    bulk_color_list: itemData?.bulk_color_list,
    length_cut_color_list: itemData?.length_cut_color_list,
    weight_cut_color_list: itemData?.weight_cut_color_list,
  })
  saleModeList.current = {
    bulk_color_list: itemData?.bulk_color_list,
    length_cut_color_list: itemData?.length_cut_color_list,
    weight_cut_color_list: itemData?.weight_cut_color_list,
  }

  const { setChangedCheckbox, currentCheckedPurchaserId, setCurrentCheckedPurchaserId, isManageStatus, setSelectedAmount, colorStore } = useShoppingContext()

  const memoList = useMemo(() => {
    return itemData?.[BackEndSaleModeListFieldMap[selected]].length !== 0 ? (
      itemData?.[BackEndSaleModeListFieldMap[selected]].map((item) => {
        console.log('memoList itemData', item)
        // 初始化选中状态
        setChangedCheckbox({
          purchaserId: itemData.purchaser_id,
          goodsKind: { [item.id]: { id: item.id, estimate_amount: item.estimate_amount, checked: false } },
          checked: false,
        })

        return <ColorKindItem purchaserId={itemData.purchaser_id} key={item.id} item={item} orderType={selected}></ColorKindItem>
      })
    ) : (
      <View className={styles.noList}>暂无数据</View>
    )
  }, [itemData, selected])

  const handleClickLayout = () => {
    if (currentCheckedPurchaserId === itemData?.purchaser_id) {
      return
    }
    console.log('handleClickLayout')
    setSelectedAmount(0)
    setCurrentCheckedSaleMode(selected)
    setCurrentCheckedPurchaserId(itemData?.purchaser_id as number)
  }

  const handleChecked = () => {
    console.log('handleChecked')
    // 初始化选中状态
    setChangedCheckbox({
      purchaserId: itemData?.purchaser_id!,
      checked: true,
    })
  }
  const handleUnchecked = () => {
    console.log('handleUnchecked')
    // 初始化选中状态
    setChangedCheckbox({
      purchaserId: itemData?.purchaser_id!,
      checked: false,
    })
  }

  return (
    <LayoutBlock
      circle
      customClassName={classnames(styles.layout, itemData?.purchaser_id === currentCheckedPurchaserId ? styles.selected : '')}
      onClick={handleClickLayout}>
      <MCheckbox
        hiddenCheckboxIcon={!isManageStatus}
        onSelect={handleChecked}
        onClose={handleUnchecked}
        status={colorStore[itemData?.purchaser_id!]?.checked}
        customClassName={styles['checkbox']}
        customTextClass={styles['checkbox--text']}
        triggerLabel={false}>
        <View className='flex-row justify-between' onClick={handleOpenDetail}>
          <View className={styles.topItem}>
            <View className='flex-row items-center'>
              <View className={styles.topTitle}>{itemData?.purchaser_name}</View>
              <Tag type='info' size='normal' circle plain>
                {itemData?.sale_user_name}
              </Tag>
            </View>
            <View className={styles.summary}>
              <Text>
                已选 {itemData?.[BackEndSaleModeListFieldMap[selected]].filter((item) => item.checked).length} 种面料，1 个颜色，共{' '}
                {selected === EnumSaleMode.Bulk ? `${4} 条` : `${4} 米`}
              </Text>
            </View>
          </View>
          <DrawerButton isOpen={openDetail} />
        </View>
      </MCheckbox>
      {/* 减少节点渲染 */}
      {openDetail && (
        <View className={classnames(styles.detailBox, openDetail ? styles.drawerOpen : styles.drawerClose)}>
          <View className={styles.orderType}>
            <Divider customClassName={styles.line}></Divider>
            <View className={styles.orderTitle}>订单类型</View>
            <View className={styles.orderTypeDetail}>
              <SaleModeButton
                customStyle={{ padding: '0 50rpx' }}
                isActive={selected === EnumSaleMode.Bulk}
                onClick={() => onSelectOrderType(EnumSaleMode.Bulk)}>
                大货
              </SaleModeButton>
              <SaleModeButton
                customStyle={{ padding: '0 50rpx' }}
                isActive={selected === EnumSaleMode.Plate}
                onClick={() => onSelectOrderType(EnumSaleMode.Plate)}>
                剪板
              </SaleModeButton>
              <SaleModeButton
                customStyle={{ padding: '0 50rpx' }}
                isActive={selected === EnumSaleMode.BulkCut}
                onClick={() => onSelectOrderType(EnumSaleMode.BulkCut)}>
                散剪
              </SaleModeButton>
            </View>
          </View>
          <View className={styles.orderColor}>
            <Divider customClassName={styles.line}></Divider>
            <View className={classnames(styles.orderTitle, 'justify-between')}>
              <Text>布料颜色</Text>
              <Tag type='danger' size='normal' circle plain={false}>
                {selectList[selected].title}单位：{selectList[selected].unit}
              </Tag>
            </View>
          </View>
          <View className={styles.orderContainer}>{memoList}</View>
        </View>
      )}
    </LayoutBlock>
  )
}, useNeedMemoCallback())

interface ButtonPropsType {
  isActive: boolean
  onClick?: Function
  children?: React.ReactNode
  customStyle?: React.CSSProperties
}
// 订单类型
const SaleModeButton: FC<ButtonPropsType> = (props) => {
  const { onClick, children, isActive = false, customStyle } = props
  const handleClick = () => {
    onClick?.()
  }
  return (
    <View className={classnames(styles.saleModeButton, isActive && styles['saleModeButton--active'])} style={customStyle} onClick={handleClick}>
      <View className={classnames(styles['saleModeButton--text'])}>{children}</View>
    </View>
  )
}
